import Web from "./Web";
import CustomActions from "./CustomActions";
import Auth from "./Auth";
import List from "./List";
import Search from "./Search";
import Profiles from "./Profiles";
import MMS from "./MMS";
export interface ContextOptions {
    token?: string;
    headers?: {
        [any: string]: string;
    };
}
export default class Context {
    /** The url of the SPScript data context */
    webUrl: string;
    /** Methods to hit the SP Search Service */
    search: Search;
    /** Methods against the SP Web object */
    web: Web;
    /** Methods to get the SP Profile Service */
    profiles: Profiles;
    /** Work with Site/Web scoped Custom Actions */
    customActions: CustomActions;
    /** Request Digest and Access token helpers */
    auth: Auth;
    /** MMS helper function for getting a termset */
    mms: MMS;
    private request;
    private ensureToken;
    private accessToken;
    headers: any;
    constructor(url: string, options?: ContextOptions);
    private executeRequest;
    /** Make a 'GET' request to the '<site>/_api' relative url. */
    get(url: string, opts?: RequestInit): Promise<any>;
    /** Make a 'POST' request to the '<site>/_api' relative url. */
    _post(url: string, body?: any, opts?: RequestInit): Promise<any>;
    /** Make a 'POST' request to the '<site>/_api' relative url. SPScript will handle authorizing the request for you.*/
    post(url: string, body?: any, verb?: string): Promise<any>;
    /** Get an SPScript List instance */
    lists(name: string): List;
    private _packagePostBody;
}
