import Context from "./Context";
export default class CustomActions {
    private ctx;
    constructor(ctx: Context);
    /** Returns both Site and Web custom actions. */
    get(): Promise<CustomAction[]>;
    /** Searches both Site and Web scoped custom actions for a name match */
    get(name: string): Promise<CustomAction>;
    private _getUrl;
    /** Update an existing Custom Action. You must pass a custom action with a 'Name' property */
    update(updates: CustomAction): Promise<any>;
    /** Remove an existing Custom Action. Searches both Site and Web scoped */
    remove(name: string): Promise<any>;
    /** Adds a new custom action. If the custom action name already exists, it will be deleted first */
    add(customAction: CustomAction): Promise<any>;
    activateExtension: (title: string, componentId: string, properties?: {}, overrides?: Partial<CustomAction>) => Promise<any>;
}
export declare type CustomActionScope = "Web" | "Site";
export interface CustomAction {
    Name: string;
    Location: string;
    /** Defaults to match Name */
    Title?: string;
    /** Defaults to match Name */
    Description?: string;
    /** Defaults to match Name */
    Group?: string;
    /** Defaults to to 100 */
    Sequence?: number;
    /** 3 for Web. 2 for Site */
    Scope?: 3 | 2;
    ScriptBlock?: string;
    /** To activate an SPFx Extension, the Component Id*/
    ClientSideComponentId?: string;
    /** Properties for configuring SPFx Extensions */
    ClientSideComponentProperties?: string;
    /** The Custom Action's primary key, guid. */
    Id?: string;
    HostProperties?: "";
}
