import { qs, parseOData } from "./utils";
var Search = /** @class */ (function () {
    function Search(ctx) {
        this._dao = ctx;
    }
    Object.defineProperty(Search.prototype, "defaultQueryOptions", {
        /** get default/empty QueryOptions */
        get: function () {
            return {
                sourceid: null,
                startrow: null,
                rowlimit: 100,
                selectproperties: null,
                refiners: null,
                refinementfilters: null,
                hiddencontstraints: null,
                sortlist: null,
            };
        },
        enumerable: true,
        configurable: true
    });
    /** Query the SP Search Service */
    Search.prototype.query = function (queryTemplate, queryOptions) {
        if (queryOptions === void 0) { queryOptions = {}; }
        var optionsQueryString = qs.fromObj(queryOptions, true);
        console.log("Search -> optionsQueryString", optionsQueryString);
        var url = "/search/query?queryTemplate='" + queryTemplate + "'&" + optionsQueryString;
        return this._dao
            .get(url)
            .then(parseOData)
            .then(function (resp) {
            return mapResponse(resp);
        });
    };
    /** Query for only People results */
    Search.prototype.people = function (queryText, queryOptions) {
        if (queryOptions === void 0) { queryOptions = {}; }
        queryOptions.sourceid = "b09a7990-05ea-4af9-81ef-edfab16c4e31";
        return this.query(queryText, queryOptions);
    };
    /** Query for only sites (STS_Web). Optionally pass in a url scope. */
    Search.prototype.sites = function (queryText, urlScope, queryOptions) {
        if (queryText === void 0) { queryText = ""; }
        if (urlScope === void 0) { urlScope = ""; }
        if (queryOptions === void 0) { queryOptions = {}; }
        urlScope = urlScope ? "Path:" + urlScope + "*" : "";
        var query = (queryText + " contentclass:STS_Web " + urlScope).trim();
        queryOptions.rowlimit = queryOptions.rowlimit || 499;
        return this.query(query, queryOptions);
    };
    return Search;
}());
export default Search;
var mapResponse = function (rawResponse) {
    return {
        elapsedTime: rawResponse.ElapsedTime,
        suggestion: rawResponse.SpellingSuggestion,
        resultsCount: rawResponse.PrimaryQueryResult.RelevantResults.RowCount,
        totalResults: rawResponse.PrimaryQueryResult.RelevantResults.TotalRows,
        totalResultsIncludingDuplicates: rawResponse.PrimaryQueryResult.RelevantResults.TotalRowsIncludingDuplicates,
        items: mapItems(rawResponse.PrimaryQueryResult.RelevantResults.Table.Rows),
        refiners: mapRefiners(rawResponse.PrimaryQueryResult.RefinementResults),
    };
};
var mapRefiners = function (refinementResults) {
    var refiners = [];
    if (refinementResults && refinementResults.Refiners && refinementResults.Refiners) {
        refiners = refinementResults.Refiners.map(function (r) {
            return {
                RefinerName: r.Name,
                RefinerOptions: r.Entries,
            };
        });
    }
    return refiners;
};
var mapItems = function (itemRows) {
    var items = [];
    for (var i = 0; i < itemRows.length; i++) {
        var row = itemRows[i], item = {};
        for (var j = 0; j < row.Cells.length; j++) {
            item[row.Cells[j].Key] = row.Cells[j].Value;
        }
        items.push(item);
    }
    return items;
};
