var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
import { parseOData } from "./utils";
/** Allows you to check the permissions of a securable (list or site) */
var Securable = /** @class */ (function () {
    function Securable(baseUrl, ctx) {
        this.baseUrl = baseUrl;
        this._dao = ctx;
    }
    /** Gets all the role assignments on that securable  */
    Securable.prototype.getRoleAssignments = function () {
        var url = this.baseUrl + "/RoleAssignments?$expand=Member,RoleDefinitionBindings";
        return this._dao
            .get(url)
            .then(parseOData)
            .then(function (results) { return results.map(transformRoleAssignment); });
    };
    Securable.prototype.checkPrivs = function (user) {
        var url = this.baseUrl + ("/getusereffectivepermissions('" + encodeURIComponent(user.LoginName) + "')");
        return this._dao.get(url).then(parseOData);
    };
    /** Gets all the role assignments on that securable. If you don't pass an email, it will use the current user. */
    Securable.prototype.check = function (email) {
        return __awaiter(this, void 0, void 0, function () {
            var user;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this._dao.web.getUser(email)];
                    case 1:
                        user = _a.sent();
                        return [2 /*return*/, this.checkPrivs(user).then(function (privs) { return permissionMaskToStrings(privs.Low, privs.High); })];
                }
            });
        });
    };
    return Securable;
}());
export default Securable;
var transformRoleAssignment = function (raw) {
    var member = {
        login: raw.Member.LoginName,
        name: raw.Member.Title,
        id: raw.Member.Id,
        principalType: raw.Member.PrincipalType,
    };
    var roles = raw.RoleDefinitionBindings.map(function (roleDef) {
        return {
            name: roleDef.Name,
            description: roleDef.Description,
            basePermissions: permissionMaskToStrings(roleDef.BasePermissions.Low, roleDef.BasePermissions.High),
        };
    });
    return { member: member, roles: roles };
};
var permissionMaskToStrings = function (lowMask, highMask) {
    var permissions = [];
    basePermissions.forEach(function (basePermission) {
        if ((basePermission.low & lowMask) > 0 || (basePermission.high & highMask) > 0) {
            permissions.push(basePermission.name);
        }
    });
    return permissions;
};
export var basePermissions = [
    {
        name: "emptyMask",
        low: 0,
        high: 0,
    },
    {
        name: "viewListItems",
        low: 1,
        high: 0,
    },
    {
        name: "addListItems",
        low: 2,
        high: 0,
    },
    {
        name: "editListItems",
        low: 4,
        high: 0,
    },
    {
        name: "deleteListItems",
        low: 8,
        high: 0,
    },
    {
        name: "approveItems",
        low: 16,
        high: 0,
    },
    {
        name: "openItems",
        low: 32,
        high: 0,
    },
    {
        name: "viewVersions",
        low: 64,
        high: 0,
    },
    {
        name: "deleteVersions",
        low: 128,
        high: 0,
    },
    {
        name: "cancelCheckout",
        low: 256,
        high: 0,
    },
    {
        name: "managePersonalViews",
        low: 512,
        high: 0,
    },
    {
        name: "manageLists",
        low: 2048,
        high: 0,
    },
    {
        name: "viewFormPages",
        low: 4096,
        high: 0,
    },
    {
        name: "anonymousSearchAccessList",
        low: 8192,
        high: 0,
    },
    {
        name: "open",
        low: 65536,
        high: 0,
    },
    {
        name: "viewPages",
        low: 131072,
        high: 0,
    },
    {
        name: "addAndCustomizePages",
        low: 262144,
        high: 0,
    },
    {
        name: "applyThemeAndBorder",
        low: 524288,
        high: 0,
    },
    {
        name: "applyStyleSheets",
        low: 1048576,
        high: 0,
    },
    {
        name: "viewUsageData",
        low: 2097152,
        high: 0,
    },
    {
        name: "createSSCSite",
        low: 4194304,
        high: 0,
    },
    {
        name: "manageSubwebs",
        low: 8388608,
        high: 0,
    },
    {
        name: "createGroups",
        low: 16777216,
        high: 0,
    },
    {
        name: "managePermissions",
        low: 33554432,
        high: 0,
    },
    {
        name: "browseDirectories",
        low: 67108864,
        high: 0,
    },
    {
        name: "browseUserInfo",
        low: 134217728,
        high: 0,
    },
    {
        name: "addDelPrivateWebParts",
        low: 268435456,
        high: 0,
    },
    {
        name: "updatePersonalWebParts",
        low: 536870912,
        high: 0,
    },
    {
        name: "manageWeb",
        low: 1073741824,
        high: 0,
    },
    {
        name: "anonymousSearchAccessWebLists",
        low: -2147483648,
        high: 0,
    },
    {
        name: "useClientIntegration",
        low: 0,
        high: 16,
    },
    {
        name: "useRemoteAPIs",
        low: 0,
        high: 32,
    },
    {
        name: "manageAlerts",
        low: 0,
        high: 64,
    },
    {
        name: "createAlerts",
        low: 0,
        high: 128,
    },
    {
        name: "editMyUserInfo",
        low: 0,
        high: 256,
    },
    {
        name: "enumeratePermissions",
        low: 0,
        high: 1073741824,
    },
];
