import Securable from "./Securable";
import { parseOData, getAddHeaders } from "./utils";
var Web = /** @class */ (function () {
    function Web(ctx) {
        this.baseUrl = "/web";
        this._dao = ctx;
        this.permissions = new Securable(this.baseUrl, ctx);
    }
    /** Retrieves basic information about the site */
    Web.prototype.getInfo = function () {
        return this._dao.get(this.baseUrl).then(parseOData);
    };
    /** Retrieves all of the subsites */
    Web.prototype.getSubsites = function () {
        return this._dao.get(this.baseUrl + "/webinfos").then(parseOData);
    };
    Web.prototype.getUser = function (email) {
        var url = email
            ? this.baseUrl + "/SiteUsers/GetByEmail('" + email + "')"
            : this.baseUrl + "/CurrentUser";
        return this._dao.get(url).then(parseOData);
    };
    Web.prototype.ensureUser = function (login) {
        return this._dao.post("/web/ensureUser('" + login + "')").then(parseOData);
    };
    /** Retrieves a file by server relative url */
    Web.prototype.getFile = function (url) {
        var url = "/web/getfilebyserverrelativeurl('" + url + "')";
        return this._dao.get(url).then(parseOData);
    };
    Web.prototype._copyFile = function (sourceUrl, destinationUrl, digest) {
        var url = "/web/getfilebyserverrelativeurl('" + sourceUrl + "')/CopyTo"; //(strnewurl='${destinationUrl}',boverwrite=true)`
        var options = {
            headers: getAddHeaders(digest),
        };
        var body = {
            strNewUrl: destinationUrl,
            bOverWrite: true,
        };
        return this._dao._post(url, body, options);
    };
    // TODO: getFolder
    // TODO: uploadFile
    // TODO: fileAction
    // TODO: deleteFile
    /** Copies a file from one server relative url to another */
    Web.prototype.copyFile = function (sourceUrl, destinationUrl, digest) {
        var _this = this;
        return this._dao.auth
            .ensureRequestDigest(digest)
            .then(function (digest) { return _this._copyFile(sourceUrl, destinationUrl, digest); });
    };
    return Web;
}());
export default Web;
